==> kdissert_0.3.8.orig.tar.gz: kdissert-0.3.8/src/templates/kdissOOOimpress.h <==
/***************************************************************************
 *   Copyright (C) 2005 Thomas Nagy                                        *
 *   tnagy2^8@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KDISSHTMLDOC_H
#define _KDISSHTMLDOC_H

#include <qstringlist.h>
#include <qobject.h>
#include <klibloader.h>
#include "DGenerator.h"

class kdissOOOimpressFactory : KLibFactory { Q_OBJECT public: QObject *createObject(QObject *, const char *, const char *, const QStringList & = QStringList()); };

class DDataItem;
class kdissOOOimpress : public DGenerator
{
    public:
	kdissOOOimpress() : DGenerator() {}
	~kdissOOOimpress() {}

	const QString identifikation();
	const QString fullName();
	const QString group();
	const QString description();
	const QString quickstart();

	static int m_piclocation;

    private:
	bool writeMaindoc(DDataItem*, const QString &);
	void writeItem(DDataItem* item, QTextStream & s, int level);

	void writeCompleteSlide(DDataItem* item, QTextStream & s);
	void writeBullet(DDataItem* item, QTextStream & s, int level);

	void writePics(DDataControl*, QString);
	void writeDownPics(DDataItem* item, QTextStream & s);
	void outputData(DDataItem* item, QTextStream & s, int level);

	/// write recursively the pics of a tree to the manifest file
	void kdissOOOimpress::writeItemPic(DDataControl*, DDataItem *item, QTextStream & m);

	static int m_slidecount;
};

#endif // _KDISSHTMLDOC_H

==> kdissert_0.9.0.orig.tar.gz: kdissert-0.9.0/src/templates/kdissOOOimpress.h <==
/***************************************************************************
 *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
 *   tnagy2^8@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation (see COPYING)            *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 ***************************************************************************/

#ifndef _KDISSOOOIMPRESS_H
#define _KDISSOOOIMPRESS_H

#include <qstringlist.h>
#include <qobject.h>
#include <klibloader.h>
#include "DGenerator.h"

class kdissOOOimpressFactory : KLibFactory { Q_OBJECT public: QObject *createObject(QObject *, const char *, const char *, const QStringList & = QStringList()); };

class DDataItem;
/**
 * OpenOffice.org impress document generator
 *
 * @short OpenOffice.org impress document generator
 * @author Thomas Nagy <tnagy2^8@yahoo.fr>
 */
class kdissOOOimpress : public DGenerator
{
    public:
	kdissOOOimpress() : DGenerator() {}
	~kdissOOOimpress() {}

	const QString identifikation();
	const QString fullName();
	const QString group();
	const QString description();
	const QString quickstart();

	static int m_piclocation;

    private:
	bool writeMaindoc(DDataItem*, const QString &);
	void writeItem(DDataItem* item, QTextStream & s, int level);

	void writeCompleteSlide(DDataItem* item, QTextStream & s);
	void writeBullet(DDataItem* item, QTextStream & s, int level);

	void writePics(DDataControl*, QString);
	void writeDownPics(DDataItem* item, QTextStream & s);
	void outputData(DDataItem* item, QTextStream & s, int level);

	/// write recursively the pics of a tree to the manifest file
	void kdissOOOimpress::writeItemPic(DDataControl*, DDataItem *item, QTextStream & m);

	static int m_slidecount;
};

#endif // _KDISSOOOIMPRESS_H
